@@ -1,13 +1,15 @@
 from revscoring.datasources.meta import dicts, filters, mappers
-
 from ...meta import aggregators
+from . import base
 
 
-class Revision:
-
-    def __init__(self, *args, **kwargs):
-        super().__init__(*args, **kwargs)
+class Revision(base.BaseRevision):
 
+    def __init__(self, name, revision_datasources, tokens_datasource=None):
+        super().__init__(name, revision_datasources)
+        if tokens_datasource is None:
+            self.cjk = Revision(name, revision_datasources.cjk, tokens_datasource='CJK')
+            "`int` : Features in the revision after the CJK tokenization"
         self.tokens = aggregators.len(self.datasources.tokens)
         "`int` : The number of tokens in the revision"
         self.numbers = aggregators.len(self.datasources.numbers)
@@ -39,7 +41,7 @@ class Revision:
         "`int` : The longest single word-token in the revision"
 
 
-class Diff:
+class Diff(base.BaseDiff):
 
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
