@@ -5,14 +5,26 @@ revscoring python package is installed, a `revscoring` utility should be
 available from the commandline.  Run `revscoring -h` for more
 information:
 
+check_model
++++++++++++
+.. automodule:: revscoring.utilities.check_model
+
 cv_train
 ++++++++
 .. automodule:: revscoring.utilities.cv_train
 
+dump_cache
+++++++++++
+.. automodule:: revscoring.utilities.dump_cache
+
 extract
 +++++++
 .. automodule:: revscoring.utilities.extract
 
+fetch_idioms
+++++++++++++
+.. automodule:: revscoring.utilities.fetch_idioms
+
 fetch_text
 ++++++++++
 .. automodule:: revscoring.utilities.fetch_text
@@ -21,6 +33,10 @@ fit
 +++
 .. automodule:: revscoring.utilities.fit
 
+intersect_merge_observations
+++++++++++++++++++++++++++++
+.. automodule:: revscoring.utilities.intersect_merge_observations
+
 model_info
 ++++++++++
 .. automodule:: revscoring.utilities.model_info
@@ -36,4 +52,12 @@ test_model
 tune
 ++++
 .. automodule:: revscoring.utilities.tune
+
+union_merge_observations
+++++++++++++++++++++++++
+.. automodule:: revscoring.utilities.union_merge_observations
+
+util
+++++
+.. automodule:: revscoring.utilities.util
 """
