@@ -6,7 +6,7 @@ from revscoring.scoring.models.model import Classifier, Learned, Model
 
 
 def test_model():
-    m = Model([Feature("foo")], version="0.0.1")
+    m = Model([Feature("foo", returns=int)], version="0.0.1")
 
     assert m.info.lookup('version') == "0.0.1"
 
@@ -24,10 +24,10 @@ def test_from_config():
 
 
 def test_learned_model():
-    model = Learned([Feature("foo")])
+    model = Learned([Feature("foo", returns=int)])
     assert model.trained is None
 
 
 def test_classifier():
-    model = Classifier([Feature("foo")], [True, False])
+    model = Classifier([Feature("foo", returns=int)], [True, False])
     assert 'statustics' not in model.info
